@@ -72,8 +72,15 @@ def has_cmake_cache_arg(cmake_args, arg_name, arg_value=None):
 
 
 def get_cmake_version(cmake_executable=CMAKE_DEFAULT_EXECUTABLE):
-    """Runs CMake and extracts associated version information.
+    """
+    Runs CMake and extracts associated version information.
     Raises :class:`skbuild.exceptions.SKBuildError` if it failed to execute CMake.
+
+    Example:
+        >>> # xdoc: IGNORE_WANT
+        >>> from skbuild.cmaker import get_cmake_version
+        >>> print(get_cmake_version())
+        3.14.4
     """
     try:
         version_string = subprocess.check_output([cmake_executable, '--version'])
@@ -88,28 +95,63 @@ def get_cmake_version(cmake_executable=CMAKE_DEFAULT_EXECUTABLE):
 
 
 class CMaker(object):
-    """Interface to CMake executable."""
+    r"""Interface to CMake executable.
+
+    Example:
+        >>> # Setup dummy repo
+        >>> from skbuild.cmaker import CMaker
+        >>> import ubelt as ub
+        >>> from os.path import join
+        >>> repo_dpath = ub.ensure_app_cache_dir('skbuild', 'test_cmaker')
+        >>> ub.delete(repo_dpath)
+        >>> src_dpath = ub.ensuredir(join(repo_dpath, 'SRC'))
+        >>> cmake_fpath = join(src_dpath, 'CMakeLists.txt')
+        >>> open(cmake_fpath, 'w').write(ub.codeblock(
+                '''
+                cmake_minimum_required(VERSION 3.5.0)
+                project(foobar NONE)
+                file(WRITE "${CMAKE_BINARY_DIR}/foo.txt" "# foo")
+                install(FILES "${CMAKE_BINARY_DIR}/foo.txt" DESTINATION ".")
+                install(CODE "message(STATUS \\"Project has been installed\\")")
+                message(STATUS "CMAKE_SOURCE_DIR:${CMAKE_SOURCE_DIR}")
+                message(STATUS "CMAKE_BINARY_DIR:${CMAKE_BINARY_DIR}")
+                '''
+        >>> ))
+        >>> # create a cmaker instance in the dummy repo, configure, and make.
+        >>> from skbuild.utils import push_dir
+        >>> with push_dir(repo_dpath):
+        >>>     cmkr = CMaker()
+        >>>     config_kwargs = {'cmake_source_dir': str(src_dpath)}
+        >>>     print('--- test cmaker configure ---')
+        >>>     env = cmkr.configure(**config_kwargs)
+        >>>     print('--- test cmaker make ---')
+        >>>     cmkr.make(env=env)
+    """
 
     def __init__(self, cmake_executable=CMAKE_DEFAULT_EXECUTABLE):
         self.cmake_executable = cmake_executable
         self.cmake_version = get_cmake_version(self.cmake_executable)
         self.platform = get_platform()
 
-    def get_cached_generator_name(self):
-        """Reads and returns the cached generator from the :func:`skbuild.constants.CMAKE_BUILD_DIR()`:.
-        Returns None if not found.
-        """
+    def get_cached(self, variable_name):
+        """If set, returns the variable cached value from the :func:`skbuild.constants.CMAKE_BUILD_DIR()`, otherwise returns None"""
+        variable_name = '{}:'.format(variable_name)
         try:
-            cmake_generator = 'CMAKE_GENERATOR:INTERNAL='
             with open(os.path.join(CMAKE_BUILD_DIR(), 'CMakeCache.txt')) as fp:
                 for line in fp:
-                    if line.startswith(cmake_generator):
-                        return line[len(cmake_generator):].strip()
+                    if line.startswith(variable_name):
+                        return line.split("=", 1)[-1].strip()
         except (OSError, IOError):
             pass
 
         return None
 
+    def get_cached_generator_name(self):
+        """Reads and returns the cached generator from the :func:`skbuild.constants.CMAKE_BUILD_DIR()`:.
+        Returns None if not found.
+        """
+        return self.get_cached('CMAKE_GENERATOR')
+
     def get_cached_generator_env(self):
         """If any, return a mapping of environment associated with the cached generator.
         """
@@ -176,6 +218,14 @@ class CMaker(object):
             cmake_executable=self.cmake_executable, cmake_args=clargs,
             languages=languages, cleanup=cleanup, architecture=cli_arch)
 
+        ninja_executable_path = None
+        if generator.name == "Ninja":
+            try:
+                import ninja
+                ninja_executable_path = os.path.join(ninja.BIN_DIR, "ninja")
+            except ImportError:
+                pass
+
         if not os.path.exists(CMAKE_BUILD_DIR()):
             os.makedirs(CMAKE_BUILD_DIR())
 
@@ -213,6 +263,8 @@ class CMaker(object):
             cmd.extend(['-T', generator.toolset])
         if generator.architecture:
             cmd.extend(['-A', generator.architecture])
+        if ninja_executable_path is not None:
+            cmd.append('-DCMAKE_MAKE_PROGRAM:FILEPATH=' + ninja_executable_path)
 
         cmd.extend(clargs)
 
@@ -253,7 +305,18 @@ class CMaker(object):
 
     @staticmethod
     def get_python_version():
-        """Get version associated with the current python interpreter."""
+        """Get version associated with the current python interpreter.
+
+        Returns:
+            str: python version string
+
+        Example:
+            >>> # xdoc: +IGNORE_WANT
+            >>> from skbuild.cmaker import CMaker
+            >>> python_version = CMaker.get_python_version()
+            >>> print('python_version = {!r}'.format(python_version))
+            python_version = '3.7'
+        """
         python_version = sysconfig.get_config_var('VERSION')
 
         if not python_version:
@@ -269,7 +332,22 @@ class CMaker(object):
     @staticmethod  # noqa: C901
     def get_python_include_dir(python_version):
         """Get include directory associated with the current python
-        interpreter."""
+        interpreter.
+
+        Args:
+            python_version (str): python version, may be partial.
+
+        Returns:
+            PathLike: python include dir
+
+        Example:
+            >>> # xdoc: +IGNORE_WANT
+            >>> from skbuild.cmaker import CMaker
+            >>> python_version = CMaker.get_python_version()
+            >>> python_include_dir = CMaker.get_python_include_dir(python_version)
+            >>> print('python_include_dir = {!r}'.format(python_include_dir))
+            python_include_dir = '.../conda/envs/py37/include/python3.7m'
+        """
         # determine python include dir
         python_include_dir = sysconfig.get_config_var('INCLUDEPY')
 
@@ -361,7 +439,22 @@ class CMaker(object):
     @staticmethod
     def get_python_library(python_version):
         """Get path to the python library associated with the current python
-        interpreter."""
+        interpreter.
+
+        Args:
+            python_version (str): python version, may be partial.
+
+        Returns:
+            PathLike: python_library : python shared library
+
+        Example:
+            >>> # xdoc: +IGNORE_WANT
+            >>> from skbuild.cmaker import CMaker
+            >>> python_version = CMaker.get_python_version()
+            >>> python_library = CMaker.get_python_include_dir(python_version)
+            >>> print('python_library = {!r}'.format(python_library))
+            python_library = '.../conda/envs/py37/include/python3.7m'
+        """
         # determine direct path to libpython
         python_library = sysconfig.get_config_var('LIBRARY')
 
@@ -376,7 +469,13 @@ class CMaker(object):
                 candidate_implementations = ['pypy-c', 'pypy3-c']
 
             candidate_extensions = ['.lib', '.so', '.a']
-            if sysconfig.get_config_var('WITH_DYLD'):
+            # On pypy + MacOS, the variable WITH_DYLD is not set. It would
+            # actually be possible to determine the python library there using
+            # LDLIBRARY + LIBDIR. As a simple fix, we check if the LDLIBRARY
+            # ends with .dylib and add it to the candidate matrix in this case.
+            with_ld = sysconfig.get_config_var('WITH_DYLD')
+            ld_lib = sysconfig.get_config_var('LDLIBRARY')
+            if with_ld or (ld_lib and ld_lib.endswith('.dylib')):
                 candidate_extensions.insert(0, '.dylib')
 
             candidate_versions = [python_version]
@@ -395,24 +494,30 @@ class CMaker(object):
             # Because calling `sysconfig.get_config_var('multiarchsubdir')`
             # returns an empty string on Linux, `du_sysconfig` is only used to
             # get the value of `LIBDIR`.
-            libdir = du_sysconfig.get_config_var('LIBDIR')
-            if sysconfig.get_config_var('MULTIARCH'):
-                masd = sysconfig.get_config_var('multiarchsubdir')
-                if masd:
-                    if masd.startswith(os.sep):
-                        masd = masd[len(os.sep):]
-                    libdir = os.path.join(libdir, masd)
-
-            if libdir is None:
-                libdir = os.path.abspath(os.path.join(
-                    sysconfig.get_config_var('LIBDEST'), "..", "libs"))
+            candidate_libdirs = []
+            libdir_a = du_sysconfig.get_config_var('LIBDIR')
+            if libdir_a is None:
+                candidate_libdirs.append(os.path.abspath(os.path.join(
+                    sysconfig.get_config_var('LIBDEST'), "..", "libs")))
+            libdir_b = sysconfig.get_config_var('LIBDIR')
+            for libdir in (libdir_a, libdir_b):
+                if libdir is None:
+                    continue
+                if sysconfig.get_config_var('MULTIARCH'):
+                    masd = sysconfig.get_config_var('multiarchsubdir')
+                    if masd:
+                        if masd.startswith(os.sep):
+                            masd = masd[len(os.sep):]
+                        candidate_libdirs.append(os.path.join(libdir, masd))
+                candidate_libdirs.append(libdir)
 
             candidates = (
                 os.path.join(
                     libdir,
                     ''.join((pre, impl, ver, abi, ext))
                 )
-                for (pre, impl, ext, ver, abi) in itertools.product(
+                for (libdir, pre, impl, ext, ver, abi) in itertools.product(
+                    candidate_libdirs,
                     candidate_lib_prefixes,
                     candidate_implementations,
                     candidate_extensions,
