@@ -1,13 +1,11 @@
 """This module defines custom implementation of ``install_scripts`` setuptools
 command."""
 
-from distutils import log as distutils_log
-
 from setuptools.command.install_scripts import (
     install_scripts as _install_scripts)
 
 from . import set_build_base_mixin
-from ..utils import distribution_hide_listing, new_style
+from ..utils import distribution_hide_listing, new_style, distutils_log
 
 
 class install_scripts(set_build_base_mixin, new_style(_install_scripts)):
